#Michelle Peziol. 2021. Mountain lion gardeners: how kill sites alter nitrogen cycling. Ecology

library(nlme)
library(lme4)
library(emmeans)
library(MuMIn)
library(AICcmodavg)


soil <- read.csv("soil_DB_2.csv")
soil$Month <- as.factor(soil$Month)
soil$KSID <- as.factor(soil$KSID)
View(soil)
attach(soil)


# nitrogen AIC table

mod0_ln <- lme(ln_Nitrogen ~ 1, random=~1|KSID, method="ML", data=soil)
mod1_ln <- lme(ln_Nitrogen ~ Month, random=~1|KSID, method="ML", data=soil)
mod2_ln <- lme(ln_Nitrogen ~ Month*WT, random=~1|KSID, method="ML", data=soil)
mod3_ln <- lme(ln_Nitrogen ~ Month*Season, random=~1|KSID, method="ML", data=soil)


require(AICcmodavg)
models = list(mod0_ln, mod1_ln, mod2_ln, mod3_ln)
modnames = c("NULL", "Month", "Month * WT", "Month * Season")
aictab(cand.set = models, modnames = modnames)



# 15 N  

mod0_ln15N <- lme(ln_15N ~ 1, random=~1|KSID, method="ML", data=soil)
mod1_ln15N <- lme(ln_15N ~ Month, random=~1|KSID, method="ML", data=soil)
mod2_ln15N <- lme(ln_15N ~ Month*WT, random=~1|KSID, method="ML", data=soil)
mod3_ln15N <- lme(ln_15N ~ Month*Season, random=~1|KSID, method="ML", data=soil)


require(AICcmodavg)
models = list(mod0_ln15N, mod1_ln15N, mod2_ln15N, mod3_ln15N)
modnames = c("NULL", "Month", "Month * WT", "Month * Season")
aictab(cand.set = models, modnames = modnames)



#calculate and plot means of fitted values based on best fit model...but, we need to back transform these

emeans_N<-emmeans(mod1_ln, ~Month)
emeans_X15N<-emmeans(mod1_ln15N, ~Month)

summary(emeans_N)
summary(emeans_X15N)

plot(emeans_N)
plot(emeans_X15N)


#multiple comparison test .tukey
library(multcomp)
library(visreg)

a<-glht(mod1_ln, linfct=mcp(Month="Tukey"))
plot(a)
summary(a)

b<-glht(mod1_ln15N, linfct=mcp(Month="Tukey"))
plot(b)
summary(b)


#residual plots for best fit model

mod1_lmer <- lmer(ln_Nitrogen ~ Month+(1 |KSID), data=soil)
plot(mod1_lmer)

mod1_lmer_15N <- lmer(ln_15N ~ Month+(1 |KSID), data=soil)
plot(mod1_lmer_15N)


emmeans(mod1_lmer_15N, ~Month)
emmeans(mod1_lmer, ~Month)


