#Peziol. 2021. Mountain lion gardeners: how kill sites alter nitrogen cycling. Ecology

library(lme4)
library(MuMIn)


APR= read.csv("april RSF.csv")
View(APR)
summary (APR)


APR$cat_ID = as.factor(APR$Cat_ID)
APR$vegetation = as.factor(APR$vegetation)


mod_tree= glmer(USEDvsAVAILABLE ~ tree + (1|cat_ID), data = APR, family = "binomial")
mod_slope= glmer(USEDvsAVAILABLE ~ slope + (1|cat_ID), data = APR, family = "binomial")
mod_forest= glmer(USEDvsAVAILABLE ~ forest + (1|cat_ID), data = APR, family = "binomial")
mod_road= glmer(USEDvsAVAILABLE ~ road + (1|cat_ID), data = APR, family = "binomial")
mod_aspect= glmer(USEDvsAVAILABLE ~ aspect + (1|cat_ID), data = APR, family = "binomial")
mod_elevation= glmer(USEDvsAVAILABLE ~ elevation + (1|cat_ID), data = APR, family = "binomial")
mod_veg= glmer(USEDvsAVAILABLE ~ vegetation + (1|cat_ID), data = APR, family = "binomial")
mod_stream= glmer(USEDvsAVAILABLE ~ stream + (1|cat_ID), data = APR, family = "binomial")

topo= glmer(USEDvsAVAILABLE ~ elevation + slope + aspect + (1|cat_ID), data = APR, family = "binomial")
distance= glmer(USEDvsAVAILABLE ~ forest + road + stream + (1|cat_ID), data = APR, family = "binomial")
landcover= glmer(USEDvsAVAILABLE ~ vegetation + tree + (1|cat_ID), data = APR, family = "binomial")

modA=glmer(USEDvsAVAILABLE ~ elevation + slope + aspect + forest + road  + stream + (1|cat_ID), data = APR, family = "binomial")
modB=glmer(USEDvsAVAILABLE ~ elevation + slope + aspect + vegetation + tree + (1|cat_ID), data = APR, family = "binomial") 
modC=glmer(USEDvsAVAILABLE ~ vegetation + forest + road + stream + tree + (1|cat_ID), data = APR, family = "binomial")

mod0= glmer(USEDvsAVAILABLE ~ 1 + (1|cat_ID), data = APR, family = "binomial")
global.model= glmer(USEDvsAVAILABLE ~ tree + slope + forest + road + stream + elevation + aspect + vegetation + (1|cat_ID), data = APR, family= binomial(logit), verbose=FALSE, nAGQ = 0)

summary(global.model)


require(AICcmodavg)
models = list(mod_tree, mod_slope, mod_forest, mod_road, mod_aspect, mod_elevation, mod_veg, mod_stream, topo, distance, landcover, global.model, mod0, modA, modB, modC)
modnames = c("tree canopy", "slope","distance to forest edge", "distance to road", "aspect", "elevation","vegetation", "distance to stream", "topography", "distance", "land cover", "global", "NULL","topography + distance","topography + land cover","landv cover + distance")
aictab(cand.set = models, modnames = modnames)


#Calculate the Area Under Curve
BMauc <- performance(pred, measure="auc") 
str(BMauc)
auc <- as.numeric(BMauc@y.values)
auc


########################################################################################################
# K-fold cross-validation
# Manual k-folds cross-validation

APR$rand.vec = sample(1:5,nrow(APR),replace=TRUE)
full.model<-glm( USEDvsAVAILABLE ~  tree + slope + forest + elevation + aspect + stream + vegetation + road, family = binomial(logit), subset=rand.vec==5, data = APR)

# Make predictions for points not used in this random subset (2:5) to fit the model.
pred.prob = predict(full.model,newdata=APR[APR$rand.vec!=5,],type="response")

# Make quantiles for the predictions - this calculates the 'bin's of the categories of habitat availability
q.pp = quantile(pred.prob,probs=seq(0,1,.1))

# Then for each of 10 bins, put each row of data into a bin
bin = rep(NA,length(pred.prob))
for (i in 1:10){
  bin[pred.prob>=q.pp[i]&pred.prob<q.pp[i+1]] = i
}

# a count of just the used locations for all other K folds 2:5 
used1 = APR$USEDvsAVAILABLE[APR$rand.vec!=5]

# We then make a table of them
rand.vec.1.table <- table(used1,bin)
rand.vec.1.table

## Spearman's rank correlation rho
cor.test(c(1, 2, 3, 4, 5, 6, 7, 8, 9, 10), c(867, 820, 824, 793, 775, 743, 723, 666, 635, 517), method="spearman")

